@@ -24,6 +24,12 @@ ghuber_sf <- function(x, y, p, a, b)
     # generalized Huber loss. Electronic Journal of Statistics 16:201-231.
     # https://doi.org/10.1214/21-EJS1957.
 
-    (abs(as.numeric(y <= x) - p)) * capping_function(x - y, a, b) *
-        (2 * (x - y) - capping_function(x - y, a, b))
+    f <- function(t, a, b)
+    {
+        capping_function(t, a, b) * (2 * t - capping_function(t, a, b))
+    }
+
+    err <- x - y
+
+    p * f(pmin(err, 0), a, b) + (1 - p) * f(pmax(err, 0), a, b)
 }
\ No newline at end of file
